import bham.leakwatch.LeakWatchAPI;
import java.security.SecureRandom;

public class GuessPresenceSingleHouse {

  // N is the total number of houses 
  static int N=3;

  // indicates the size of the target. Only one of those should be one and all the other 0.
  static int target_is_S = 1 ;
  static int target_is_M = 0 ;
  static int target_is_L = 0 ;

  // We consider different sizes of houses. S, M and L indicate the number of houses of each size.
  static int S=N/3 - target_is_S ;
  static int M=N/3 - target_is_M ;
  static int L=N/3 - target_is_L ;

  // each size correspond to a different level of consumption
  static int  small_consumption = 1 ;
  static int medium_consumption = 3 ;
  static int  large_consumption = 5 ;

  // the observable is the global consumption of the system
  static int global_consumption =0 ;

  //  the presence of people in each house
  static  int[] presence;
  // the secret is the presence 
  static int presence_target;

  static void error(){
    System.out.println("Usage: GuessPresenceSingleHouse <nb_houses> <target type> [case1|case2]");
    System.out.println("<target type> is either S M or L");
    System.exit(1);
  }

  static void numberOfEach(){
    S=N/3 - target_is_S ;
    M=N/3 - target_is_M ;
    L=N/3 - target_is_L ;
  }


  static void initPublicValues(String[] args) {
    if (args.length<2) error();
    N=Integer.parseInt(args[0]);
    S=N/3 ;
    M=N/3 ;
    L=N-S-M ;

    if (args.length > 2) {
      if (args[2].equals("case1")) {
	small_consumption = 1 ;
	medium_consumption = 2 ;
	large_consumption = 3 ;
      }
      else {
	small_consumption = 1 ;
	medium_consumption = 3 ;
	large_consumption = 5 ;
      }
    }
    if (args[1].equals("L")){
      target_is_S = 0 ;
      target_is_M = 0 ;
      target_is_L = 1 ;
      numberOfEach();
    } else if (args[1].equals("M")){
      target_is_S = 0 ;
      target_is_M = 1 ;
      target_is_L = 0 ;
      numberOfEach();
    } else if (args[1].equals("S")){
      target_is_S = 1 ;
      target_is_M = 0 ;
      target_is_L = 0 ;
      numberOfEach();
    } else {
      error();
    }
  }

  static void initPrivateValues() {
    SecureRandom rand = new SecureRandom(); 
    presence = new int[N-1];
    for(int i =0; i<N-1 ; i++){
      presence[i]=rand.nextInt(2);
    }
    presence_target=rand.nextInt(2);
    LeakWatchAPI.secret("presence_target",presence_target);
  }


  public static void main(String[] args){
    initPublicValues(args);
    // init private values in the intervals defined in QUAIL file
    initPrivateValues();
    if  (presence_target == 1) {
      if  (target_is_S == 1) {
	global_consumption= global_consumption + small_consumption ;
      } 
      else if (target_is_M == 1) {
	global_consumption= global_consumption + medium_consumption ;
      }
      else {
	global_consumption= global_consumption + large_consumption ;
      }
    }

    int i  = 0;
    while ( i < N-1) {
      if (presence[i] == 1) {
	if (i<S) {
	  global_consumption = global_consumption + small_consumption ;
	}
	else if (i<S+M) {
	  global_consumption = global_consumption + medium_consumption ;
	}
	else{
	  global_consumption = global_consumption + large_consumption ;
	}
      }
      i= i + 1;
    }
    LeakWatchAPI.observe(global_consumption);
  }

}
